@@ -17,9 +17,10 @@ Test class for iRMC Power Driver
 
 import os
 import time
+from unittest import mock
 import xml.etree.ElementTree as ET
 
-import mock
+import defusedxml.ElementTree as dET
 from requests_mock.contrib import fixture as rm_fixture
 import six
 import six.moves.builtins as __builtin__
@@ -34,6 +35,103 @@ if six.PY3:
     file = io.BytesIO
 
 
+IRMC_CONFIG_PARTIAL = """<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
+<CMDSEQ>
+<!-- "Many Items Ommited..." -->
+<!-- "ConfBmcRemoteFdImageServer" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A50" OI="0" Type="SET">
+  <DATA Type="xsd::string">10.124.196.156</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageUserName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A51" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageUserPassword" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A52" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageUserDomain" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A53" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageShareType" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A54" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageShareName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A55" OI="0" Type="SET">
+  <DATA Type="xsd::string">/srv/nfs</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteFdImageImageName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A56" OI="0" Type="SET">
+  <DATA Type="xsd::string">virtual-media.img</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcMediaOptionsFdAttachMode" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A57" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcMediaOptionsFdNumber" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A58" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageServer" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A60" OI="0" Type="SET">
+  <DATA Type="xsd::string">10.124.196.156</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageUserName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A61" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageUserPassword" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A62" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageUserDomain" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A63" OI="0" Type="SET">
+  <DATA Type="xsd::string"></DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageShareType" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A64" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageShareName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A65" OI="0" Type="SET">
+  <DATA Type="xsd::string">/srv/nfs</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcRemoteCdImageImageName" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A66" OI="0" Type="SET">
+  <DATA Type="xsd::string">virtual-media.iso</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcMediaOptionsCdAttachMode" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A67" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "ConfBmcMediaOptionsCdNumber" -->
+<CMD Context="SCCI" OC="ConfigSpace" OE="1A68" OI="0" Type="SET">
+  <DATA Type="xsd::integer">1</DATA>
+  <STATUS>0</STATUS>
+</CMD>
+<!-- "Many Items Ommited..." -->
+</CMDSEQ>"""
+
+
 class SCCITestCase(testtools.TestCase):
     """Tests for SCCI
 
@@ -49,13 +147,13 @@ class SCCITestCase(testtools.TestCase):
                 os.path.dirname(__file__),
                 'fixtures/irmc_report_ok.xml'), "r") as report_ok:
             self.report_ok_txt = report_ok.read()
-        self.report_ok_xml = ET.fromstring(self.report_ok_txt)
+        self.report_ok_xml = dET.fromstring(self.report_ok_txt)
 
         with open(os.path.join(
                 os.path.dirname(__file__),
                 'fixtures/irmc_report_ng.xml'), "r") as report_ng:
             self.report_ng_txt = report_ng.read()
-        self.report_ng_xml = ET.fromstring(self.report_ng_txt)
+        self.report_ng_xml = dET.fromstring(self.report_ng_txt)
 
         self.irmc_address = '10.124.196.159'
         self.irmc_username = 'admin'
@@ -663,6 +761,9 @@ class SCCITestCase(testtools.TestCase):
                                 <Message>No Error</Message>
                                 </Status>""")
 
+        self.requests_mock.get("http://" + self.irmc_address +
+                               "/iRMC_Settings.pre", text=IRMC_CONFIG_PARTIAL)
+
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
                                  self.irmc_password,
